# Django Bank Details

[django-bank-details](https://github.com/hungryseven/django-bank-requisites)

# Overview

This package provides models, serializers, mixins and validators for russian bank requisites such as
INN, KPP, BIK, RS, KS, OGRN and so on.